Coverage for __init__.py: 100%

# Coverage for __init__.py : 100%

## 3 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 version_info = (4, 4, 3)

2 __version__ = ".".join([str(v) for v in version_info])

3

4

5"""

6

7 4.4.3

8

9- Fix initialise, add SHOPYO_CONFIG_PROFILE env var to denote configuration profiles

10

11 4.4.2

12

13- Fix email-validator version

14

15 4.4.1

16

17- Fix app.py on new projects

18- Fix validator required in reqs

19- Fix remove settings functions from www.view

20

21 4.4.0

22

23- Add global configs via module

24

25 4.3.7

26

27- Remove 3.6 support

28

29"""